@@ -71,7 +71,7 @@ class Table(object):
         Used to get all data in one column.
 
         :param col_name: The name of the column you wish to get.
-        :return: A list of all data in one column.
+        :return: A list of all data in one column (column name not included).
         """
         col_position = self.table_content[0].index(col_name)
         temp_table_content = self.table_content[:]
@@ -109,7 +109,7 @@ class Table(object):
          Used to add a column that is based on another column.
 
         :param new_col_name: The new name for your column.
-        :param formula: The formula for your expand. `More information <expandformula.html>`_.
+        :param formula: The formula (string) for your expand. Use @ signs to name your column names. For example :code:`"@col_name@"`. The return result will be in your result. You can use built-in python functions. Example: :code:`str(int(@col_name@) + 10) + @another_col_name@`
         :return:
         """
 
@@ -120,7 +120,7 @@ class Table(object):
          Used to override a column that is based on another column.
 
         :param col_name: The name of the column that you want to override.
-        :param formula: The formula for your expand. `More information <expandformula.html>`_
+        :param formula: The formula (string) for your expand. Use @ signs to name your column names. For example :code:`"@col_name@"`. The return result will be in your result. You can use built-in python functions. Example: :code:`str(int(@col_name@) + 10) + @another_col_name@`
         :return:
         """
 
@@ -153,6 +153,13 @@ class Table(object):
                 self.table_content[i + 1].append(default_value[i])
 
     def edit_row(self, row_num, new_value):
+        """
+        Used to edit a row.
+
+        :param row_num: The row number to edit.
+        :param new_value: Use a list override a row. If you use a dictionary, the key will be the column name.
+        :return:
+        """
         if type(new_value) is not dict and type(new_value) is not list:
             raise TypeError("Only types 'dict' and 'list' are excepted")
 
@@ -176,14 +183,13 @@ class Table(object):
         """
         self.table_content[row_num][self.table_content[0].index(col_name)] = new_value
 
-    def filter(self, formula, search_start=1, search_end="END", add_headers_to_result=True):
+    def filter(self, formula, search_start=1, search_end="END"):
         """
         Used to filter your table.
 
-        :param formula: The formula for your filter. `More information <filterformula.html>`_
+        :param formula: The formula (string) for your filter. Use @ signs to name your column names. For example :code:`@col_name@`. You can write your filter just like an if statement. Example: :code:`@col_name@ == 'hello'` You can use built-in python functions. Example: :code:`float(@col_name@) + float(@another_col_name@) > 10`
         :param search_start: The row to start filtering at.
         :param search_end: The row to stop filtering at. Type "END" to stop at the end.
-        :param add_headers_to_result: If True, your table headers will be included in the result.
         :return: A Table object with the filtered results.
         """
         if search_end == "END":
@@ -199,9 +205,7 @@ class Table(object):
             if eval(current_formula):
                 result_list.append(i[1])
 
-        if add_headers_to_result:
-            result_list.insert(0, self.table_content[0])
-
+        result_list.insert(0, self.table_content[0])
         temp_table = Table()
         temp_table.table_content = result_list
         return temp_table
